@@ -12,7 +12,7 @@
 """
 __author__ = 'liaozhaoyan'
 
-from .tags import Tag, Root, Fragment, Literal, XMLDeclaration
-from .paths import Path
+from .tag import T, Literal, SVG
+from .path import Cell, Path
 from .packer import Packer
 from .flame import Flame
