@@ -15,7 +15,7 @@ __author__ = 'liaozhaoyan'
 import os
 from treelib import Tree
 from random import randrange
-from .tags import Tag, Root, Literal
+from .tag import T, SVG, Literal
 
 flameHead = '''<?xml version="1.0" standalone="no"?>
 <!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN" "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd">\n'''
@@ -89,18 +89,17 @@ class Flame(object):
                 y = self._calY(yBeg, level)
                 width = self._calWidth(node, parent, stack[level - 1][1], cbValue)
             if (len(node.tag) + 1) * 6 > width:
-                text = ""
+                text = " "
             else:
                 text = node.tag
-            g = Tag.g()(
-                Tag.title("%s" % node.tag),
-                Tag.desc("%s (%s)" % (node.tag, cbNote(node.data))),
-                Tag.rect(x=x, y=y,
-                         width=width, height=self._barHeigh,
-                         fill=flameColor(),
-                         rx=2, ry=2
-                         ),
-                Tag.text(text, x=x+3, y=y+10.5)
+            g = T.g()(
+                T.title("%s" % node.tag),
+                T.desc("%s (%s)" % (node.tag, cbNote(node.data))),
+                T.rect(x=x, y=y,
+                       width=width, height=self._barHeigh,
+                       fill=flameColor(),
+                       rx=2, ry=2),
+                T.text(text, x=x+3, y=y+10.5)
             )
             if len(stack) > level:
                 stack[level] = (x, width, x + width)
@@ -112,39 +111,39 @@ class Flame(object):
 
     def _setupCells(self, tree, cbValue, cbNote, title):
         height = self._yBeg + (tree.depth() + 3) * self._barHeigh
-        defs = Tag.defs()(
-            Tag.linearGradient(id="background", y1=0, y2=1, x1=0, x2=0)(
-                Tag.stop(stop_color="#eeeeee", offset="5%"),
-                Tag.stop(stop_color="#eeeeb0", offset="95%"),
+        defs = T.defs()(
+            T.linearGradient(id="background", y1=0, y2=1, x1=0, x2=0)(
+                T.stop(stop_color="#eeeeee", offset="5%"),
+                T.stop(stop_color="#eeeeb0", offset="95%"),
             ),
         )
-        css = Tag.style(Literal(self._loadCSS(), escape=False), type="text/css")
-        script = Tag.script(Literal(self._loadScript(), escape=False), type="text/ecmascript")
-        rect = Tag.rect(x=0.0, y=0, width=1200.0, height=height, fill="url(#background)")
-        title = Tag.text(title, id="title", x=600.00, y=24)
-        details = Tag.text("", id="details", x=10.00, y=height - 1.0 * self._barHeigh)
-        unzoom = Tag.text("Reset Zoom", id="unzoom", _class="hide", x=10.00, y=24)
-        search = Tag.text("Search", id="search", x=1090, y=24)
-        matched = Tag.text(id="matched", x=1090, y=height - 1.0 * self._barHeigh)
-        frames = Tag.g(id="frames")(
+        css = T.style(Literal(self._loadCSS(), esc=False), type="text/css")
+        script = T.script(Literal(self._loadScript(), esc=False), type="text/ecmascript")
+        rect = T.rect(x=0.0, y=0, width=1200.0, height=height, fill="url(#background)")
+        title = T.text(title, id="title", x=600.00, y=24)
+        details = T.text(" ", id="details", x=10.00, y=height - 1.0 * self._barHeigh)
+        unzoom = T.text("Reset Zoom", id="unzoom", _class="hide", x=10.00, y=24)
+        search = T.text("Search", id="search", x=1090, y=24)
+        matched = T.text(id="matched", x=1090, y=height - 1.0 * self._barHeigh)
+        frames = T.g(id="frames")(
             *self._setupFrame(tree, cbValue, cbNote)
         )
         return tuple([defs, css, script, rect, title, details, unzoom, search, matched, frames])
 
-    def _setupRoot(self, tree, cbValue, cbNote, title, pretty=False):
-        root = Root(version="1.1",
-                    width="1200",
-                    height="870",
-                    onload="init(evt)",
-                    viewBox="0 0 1200 870",
-                    use_namespace=True)(
+    def _setupRoot(self, tree, cbValue, cbNote, title):
+        root = SVG(version="1.1",
+                   width="1200",
+                   height="870",
+                   onload="init(evt)",
+                   viewBox="0 0 1200 870",
+                   useNS=True)(
             *self._setupCells(tree, cbValue, cbNote, title)
         )
-        return root.render(pretty)
+        return root.build()
 
-    def render(self, tree, cbValue, cbNote, title="Flame Graph", pretty=True):
+    def render(self, tree, cbValue, cbNote, title="Flame Graph"):
         s = flameHead
-        s += self._setupRoot(tree, cbValue, cbNote, title, pretty)
+        s += self._setupRoot(tree, cbValue, cbNote, title)
         with open(self._file, 'w') as f:
             f.write(s)
 
