@@ -21,8 +21,8 @@ class Packer(object):
         super(Packer, self).__init__()
         self._path = filePath
 
-    def render(self, tree, pretty=True):
-        s = svgHead + tree.render(pretty)
+    def render(self, svg):
+        s = svgHead + svg.build()
         with open(self._path, "w") as f:
             f.write(s)
 
